#
# spec file for package gnome-initial-setup
#
# Copyright (c) 2019 SUSE LINUX GmbH, Nuernberg, Germany.
#
# All modifications and additions to the file contributed by third parties
# remain the property of their copyright owners, unless otherwise agreed
# upon. The license for this file, and modifications and additions to the
# file, is the same license as for the pristine package itself (unless the
# license for the pristine package is not an Open Source License, in which
# case the license is the MIT License). An "Open Source License" is a
# license that conforms to the Open Source Definition (Version 1.9)
# published by the Open Source Initiative.

# Please submit bugfixes or comments via https://bugs.opensuse.org/
#


Name:           gnome-initial-setup
Version:        3.34.6
Release:        lp152.1.1
Summary:        GNOME Initial Setup Assistant
License:        GPL-2.0-or-later
Group:          System/GUI/GNOME
Url:            https://wiki.gnome.org/Design/OS/InitialSetup
Source0:        https://download.gnome.org/sources/gnome-initial-setup/3.34/%{name}-%{version}.tar.xz
# PATCH-FEATURE-SLE gnome-initial-setup-smarter.patch FATE#325763 FATE#321126 boo#1067288 bnc#1029083 qzhao@suse.com -- Investigate gnome-initial-setup, and make a Smarter gnome initial configuration.
Patch0:         gnome-initial-setup-smarter.patch
BuildRequires:  krb5-devel
BuildRequires:  meson
BuildRequires:  pkgconfig
BuildRequires:  vala
BuildRequires:  pkgconfig(accountsservice)
BuildRequires:  pkgconfig(cheese)
BuildRequires:  pkgconfig(cheese-gtk) >= 3.3.5
BuildRequires:  pkgconfig(fontconfig)
BuildRequires:  pkgconfig(gdm) >= 3.8.3
BuildRequires:  pkgconfig(geocode-glib-1.0)
BuildRequires:  pkgconfig(gio-unix-2.0) >= 2.53.0
BuildRequires:  pkgconfig(gnome-desktop-3.0) >= 3.7.5
BuildRequires:  pkgconfig(goa-1.0)
BuildRequires:  pkgconfig(goa-backend-1.0)
BuildRequires:  pkgconfig(gobject-introspection-1.0)
BuildRequires:  pkgconfig(gstreamer-1.0)
BuildRequires:  pkgconfig(gtk+-3.0) >= 3.11.3
BuildRequires:  pkgconfig(gweather-3.0)
BuildRequires:  pkgconfig(ibus-1.0) >= 1.4.99
BuildRequires:  pkgconfig(iso-codes)
BuildRequires:  pkgconfig(json-glib-1.0)
BuildRequires:  pkgconfig(libgeoclue-2.0) >= 2.3.1
BuildRequires:  pkgconfig(libnm) >= 1.2
BuildRequires:  pkgconfig(libnma) >= 1.0
BuildRequires:  pkgconfig(libsecret-1)
BuildRequires:  pkgconfig(packagekit-glib2)
BuildRequires:  pkgconfig(pango) >= 1.32.5
BuildRequires:  pkgconfig(polkit-gobject-1) >= 0.103
BuildRequires:  pkgconfig(pwquality)
BuildRequires:  pkgconfig(rest-0.7)
BuildRequires:  pkgconfig(systemd)
BuildRequires:  pkgconfig(webkit2gtk-4.0)
# Remove the yelp document dependency on both sle and leap, keeping tw consistent with upstream
%if !0%{?sle_version}
Requires:       gnome-getting-started-docs
%endif

%description
Initial assistant, helping you to get the system up and running.

%lang_package

%prep
%setup -q
%if 0%{?sle_version} >= 150200
%patch0 -p1
%endif


%build
%meson \
	%{nil}
%meson_build

%install
%meson_install
%if 0%{?sle_version} >= 150200
rm -rf %{buildroot}%{_libexecdir}/gnome-welcome-tour
rm -rf %{buildroot}%{_sysconfdir}/xdg/autostart/gnome-welcome-tour.desktop
%endif
%find_lang %{name} %{?no_lang_C}

%pre
useradd -rM -d /run/gnome-initial-setup/ -s /sbin/nologin %{name} || :

%files
%license COPYING
%doc README
%dir %{_datadir}/gdm
%dir %{_datadir}/gdm/greeter
%dir %{_datadir}/gdm/greeter/applications
%{_datadir}/gdm/greeter/applications/gnome-initial-setup.desktop
%dir %{_datadir}/gnome-session
%dir %{_datadir}/gnome-session/sessions
%{_datadir}/gnome-session/sessions/gnome-initial-setup.session
%dir %{_datadir}/gnome-shell
%dir %{_datadir}/gnome-shell/modes
%{_datadir}/gnome-shell/modes/initial-setup.json
%{_datadir}/polkit-1/rules.d/20-gnome-initial-setup.rules
%{_libexecdir}/gnome-initial-setup
%{_libexecdir}/gnome-initial-setup-copy-worker
%{_sysconfdir}/xdg/autostart/gnome-initial-setup-copy-worker.desktop
%{_sysconfdir}/xdg/autostart/gnome-initial-setup-first-login.desktop
%{_userunitdir}/gnome-initial-setup-copy-worker.service
%{_userunitdir}/gnome-initial-setup-first-login.service
%{_userunitdir}/gnome-initial-setup.service
%dir %{_userunitdir}/gnome-session.target.wants
%{_userunitdir}/gnome-session.target.wants/gnome-initial-setup-copy-worker.service
%{_userunitdir}/gnome-session.target.wants/gnome-initial-setup-first-login.service
%dir %{_userunitdir}/gnome-session@gnome-initial-setup.target.wants
%{_userunitdir}/gnome-session@gnome-initial-setup.target.wants/gnome-initial-setup.service
%if 0%{?sle_version} < 150200
%{_userunitdir}/gnome-welcome-tour.service
%{_userunitdir}/gnome-session.target.wants/gnome-welcome-tour.service
%{_libexecdir}/gnome-welcome-tour
%{_sysconfdir}/xdg/autostart/gnome-welcome-tour.desktop
%endif

%files lang -f %{name}.lang

%changelog
* Tue May 12 2020 Michael Gorse <mgorse@suse.com>
- Update to version 3.34.6 (bsc#1171501):
  + Updated translations.
* Mon Apr 27 2020 Cliff Zhao <qzhao@suse.com>
- Update gnome-initial-setup.spec, gnome-initial-setup-smarter.patch:
  Avoid the boot error message and gnome "getting started" help
  messages(bnc#1158488, bnc#1166008).
* Wed Apr 15 2020 Cliff Zhao <qzhao@suse.com>
- Update gnome-initial-setup.spec: Drop the is_opensuse macro to
  eliminate in behavior in between SLE-15 and openSUSE-Leap
  (jsc#SLE-11857).
* Sat Jan 25 2020 Dominique Leuenberger <dimstar@opensuse.org>
- No longer recommend -lang: supplements are in use
* Sun Jan  5 2020 Bjørn Lie <bjorn.lie@gmail.com>
- Update to version 3.34.3:
  + Updated translations.
* Tue Nov 26 2019 Cliff Zhao <qzhao@suse.com>
- Update gnome-initial-setup-smarter.patch: Rebase to
  gnome-initial-setup-3.34.1 for SLE-15-SP2 build(bnc#1156952).
* Thu Oct 24 2019 Cliff Zhao <qzhao@suse.com>
- Update gnome-initial-setup.spec
  Drop gnome-initial-setup-disable-dep-on-started-docs.patch
  Drop gnome-initial-setup-mozc-engine-prioritized.patch
  Drop gnome-initial-setup-only-setup-keyboard.patch
  Drop gnome-initial-setup-only-launch-CJK.patch
  to avoid blank docs window appear after gnome-initial-setup
  finished (bnc#1125694, bnc#1131087).
* Sat Oct  5 2019 Bjørn Lie <bjorn.lie@gmail.com>
- Update to version 3.34.1:
  + Bugs fixed:
  - Mark “Accept” button as suggested action
  - Disable g-i-s in GDM.
  + Updated translations.
* Tue Sep 24 2019 Felix Zhang <fezhang@suse.com>
- Fix unpackaged files in specfile.
* Wed Sep 18 2019 Bjørn Lie <bjorn.lie@gmail.com>
- Update to version 3.34.0:
  + Bugs fixed: Fixes for systemd user instance support.
  + Updated translations.
* Sat Aug 31 2019 mgorse@suse.com
- Update to version 3.33.92:
  + Translation updates.
  + Changes in version 3.33.91:
  + build: Add a log domain.
  + Translation updates.
  + Changes in version 3.33.90:
  + systemd user instance support. This is inert without
    corresponding changes in other GNOME modules, and can be
    disabled entirely with `-Dsystemd=false` at build time.
  + Other improvements and bug fixes:
  - summary: don't free borrowed password string.
  - data: use a11y menu in initial-setup session.
  - driver: Account for multi monitor when checking for small screen.
  - language: Refactor the logo selection.
  - language: Fix the visibility of the placeholder.
  - summary: Make the page fit narrow screens.
  - Drop the headers for the first rows.
  - account: Drop the avatar button padding.
  - Refactor page headers.
  - data: Update required gnome-settings-daemon plugins.
  + Translation updates.
  + Changes in version 3.33.4:
  + Bugs fixed:
  - Check for errors from newlocale().
  + Translation updates.
  + Changes in version 3.33.2:
  + Bugs fixed:
  - setlocale() usage is not threadsafe.
  - Include bug report URL in .pot file
  + Translation updates.
- Rebase gnome-initial-setup-only-setup-keyboard.patch.
- Depend on systemd.
- Remove setup-shell.desktop from files.
- Add user systemd targets to files.
* Fri Apr  5 2019 Bjørn Lie <bjorn.lie@gmail.com>
- Update to version 3.32.1:
  + Updated translations.
* Mon Mar 11 2019 Bjørn Lie <bjorn.lie@gmail.com>
- Update to version 3.32.0:
  + Updated translations.
* Tue Mar  5 2019 Bjørn Lie <bjorn.lie@gmail.com>
- Update to version 3.31.92:
  + Connect to GDM as soon as gnome-initial-setup starts and fix
    memory leaks.
  + Improve account page behaviour when offline.
  + Updated translations.
* Wed Feb 27 2019 qzhao@suse.com
- Update gnome-initial-setup-smarter.patch:
  Avoid duplicate privilege requirement(FATE#321126).
* Wed Feb 20 2019 bjorn.lie@gmail.com
- Update to version 3.31.90:
  + Generate default user account pictures.
  + Fix Meson build with (buggy) Meson 0.48.0 and 0.48.1.
  + Remove Autotools build.
  + Fix various compiler warnings.
  + Add welcome distro logo for openSUSE.
  + Updated translations.
- Switch to meson build system, add meson BuildRequires and macros.
- Drop obsolete intltool BuildRequires: No longer needed.
- Add pkgconfig(packagekit-glib2) BuildRequires: New dependency.
- Refresh patch with refresh_patches service.
* Wed Dec 19 2018 qzhao@suse.com
- Add gnome-initial-setup-smarter.patch,
  Smarter gnome initial configuration: Find a method (better
  upstream compatible) to allow gnome-initial-setup decide the
  pop-ups smartly based on the system wise setup provided by the
  installer(FATE#325763).
  Adapt previous solutions to satisfy this feature. (FATE#321126,
  boo#1067288, bnc#1029083).
* Wed Sep 26 2018 bjorn.lie@gmail.com
- Update to version 3.30.0:
  + Updated translations.
* Sun Sep  2 2018 luc14n0@linuxmail.org
- Update to version 3.29.92:
  + Improved network page.
  + Fix timezone selection in new-user mode.
  + Properly use libsecret unstable api.
  + Updated translations.
* Fri Aug  3 2018 bjorn.lie@gmail.com
- Update to version 3.29.1:
  + Support more general page skipping.
  + Show the welcome page if the language page is skipped.
  + Look for vendor.conf in /usr/share instead of /var.
  + Go back to allowing weak passwords.
  + Set keyring password for enterprise accounts.
  + Use Debian, Ubuntu logos when appropriate.
  + Fix a crash.
  + Add meson support.
  + Use a new avatar chooser.
  + Updated translations.
* Tue Mar 27 2018 yfjiang@suse.com
- Rebase gnome-initial-setup-disable-dep-on-started-docs.patch: The
  run-welcome-tour stamp file is moved to a global function as
  stated in bgo#777707.
- Enable the following patches on Leap 42.3, Leap 15 and
  later, being consistent with SLE (boo#1086056):
  + gnome-initial-setup-only-launch-CJK.patch
  + gnome-initial-setup-only-setup-keyboard.patch
  + gnome-initial-setup-disable-dep-on-started-docs.patch
- Remove the dependency of gnome-getting-started-docs on Leap, being
  consistent with SLE (boo#1086056).
- Url link fix in spec.
* Tue Mar 13 2018 dimstar@opensuse.org
- Update to version 3.28.0:
  + Sync string changes with gnome-software.
  + Updated translations.
* Wed Feb 28 2018 dimstar@opensuse.org
- Modernize spec-file by calling spec-cleaner
* Tue Feb 27 2018 sbrabec@suse.com
- Add missing lang package Recommends (bsc#1038022).
* Sat Feb 10 2018 bjorn.lie@gmail.com
- Update to version 3.27.90:
  + Adjust session components to recent changes.
  + Improve sorting in the language list.
  + Memory leak fixes.
  + Update titlebar when title changes.
  + Updated translations.
* Thu Nov  9 2017 qzhao@suse.com
- Add gnome-initial-setup-mozc-engine-prioritized.patch: Make the
  Mozc input engine as the 1st choice for Japanese environment
  (boo#1067288,bnc#1029083).
* Fri Sep 15 2017 qzhao@suse.com
- Update gnome-initial-setup-disable-dep-on-started-docs.patch:
  Porting to gnome-initial-setup version 3.26.0.
* Mon Sep 11 2017 zaitor@opensuse.org
- Update to version 3.26.0:
  + Updated translations.
* Mon Sep  4 2017 zaitor@opensuse.org
- Update to version 3.25.92:
  + Updated translations.
* Wed Jul 19 2017 zaitor@opensuse.org
- Update to version 3.25.4:
  + Use Unicode in translatable strings.
  + Adjust to g-s-d's plugin removals.
  + Updated translations.
* Thu Jun 22 2017 zaitor@opensuse.org
- Update to version 3.25.3:
  + Support a vendor configuration file.
  + Update text direction when the locale changes.
  + Allow configuring network connections.
  + Copy monitor configuration to user session.
  + Sync user account page with control-center.
  + Show strength indicator for passwords.
* Thu Jun  1 2017 qzhao@suse.com
- Update gnome-initial-setup-only-setup-keyboard.patch
  gnome-initial-setup-disable-dep-on-started-docs.patch: Porting
  these patches to gnome-initial-setup version 3.24.2.
* Wed May 10 2017 zaitor@opensuse.org
- Update to version 3.24.2:
  + Updated translations.
* Tue Mar 21 2017 dimstar@opensuse.org
- Update to version 3.24.0:
  + Fix g-i-s session startup deadlock.
  + Updated translations.
* Tue Mar 14 2017 dimstar@opensuse.org
- Update to version 3.23.92:
  + Use correct capitalization and unicode characters.
  + Exit gracefully when disabled systemwide.
  + Adjust to gnome-settings-daemon changes.
  + Port network page to use libnm instead of libnm-glib.
  + Updated translations.
- Update BuildRequires relating to upstreams port to libnm:
  + Remove pkgconfig(libnm-glib), pkgconfig(libnm-gtk) and
    pkgconfig(libnm-util).
  + Add pkgconfig(libnm) and pkgconfig(libnma).
* Wed Nov  9 2016 dimstar@opensuse.org
- Update to version 3.23.1:
  + Clarify presentation of privacy policies.
  + Updated translations.
* Mon Oct 10 2016 zaitor@opensuse.org
- Update to version 3.22.1:
  + Clarify privacy policy links.
  + Updated translations.
* Mon Sep 19 2016 dimstar@opensuse.org
- Update to version 3.22.0:
  + Updated translations.
* Tue Sep 13 2016 zaitor@opensuse.org
- Update to version 3.21.92:
  + Port timezone page to use new Geoclue convencience library.
  + Minor UI fixes on privacy page.
  + Correct license of um-realm-manager.
  + Updated translations.
- Replace pkgconfig(geoclue-2.0) for pkgconfig(libgeoclue-2.0), and
  add pkgconfig(geocode-glib-1.0) BuildRequires following upstreams
  port.
* Thu Sep  1 2016 zaitor@opensuse.org
- Update to version 3.21.91:
  + Better handling of small screens.
  + Add a page to configure software sources.
  + Updated translations.
* Mon May 23 2016 yfjiang@suse.com
- Add gnome-initial-setup-disable-dep-on-started-docs.patch:
  Dismiss the yelp help page after the initial setup
  (FATE#321126).
* Mon May 16 2016 yfjiang@suse.com
- Add gnome-initial-setup-only-setup-keyboard.patch: Only setup the
  keyboard and IM as required (FATE#321126).
* Tue May 10 2016 qzhao@suse.com
- Add gnome-initial-setup-only-launch-CJK.patch: In SLED, it will
  active if user's language is Chinese/Japanese/Korean, and
  deactive in other language (FATE#321126).
* Sun May  8 2016 qzhao@suse.com
- Import gnome-initial-setup to SLE12:SP3(FATE#321126, bsc#988350).
* Tue Apr 12 2016 zaitor@opensuse.org
- Update to version 3.20.1:
  + Updated translations.
* Thu Apr  7 2016 zaitor@opensuse.org
- Drop pkgconfig(clutter-gst-2.0) and pkgconfig(clutter-x11-1.0)
  BuildRequires: Not hard dependencies anymore.
- Add pkgconfig(json-glib-1.0) BuildRequires: Configure looks for
  it, so add it to make sure it's pulled in.
* Mon Mar 21 2016 dimstar@opensuse.org
- Update to version 3.20.0:
  + Updated translations.
* Tue Mar 15 2016 dimstar@opensuse.org
- Update to version 3.19.92:
  + Add a translator comment for 'Welcome!'.
  + Updated translations.
* Tue Mar  1 2016 zaitor@opensuse.org
- Update to version 3.19.91:
  + Visual refinements on online accounts page.
  + Minor tweaks on the privacy and accounts pages.
  + Ensure keyring gets created for new users.
  + Updated translations.
- Changes from version 3.19.90:
  + Visual refresh for the 'ready to go' page.
* Mon Feb 22 2016 dimstar@opensuse.org
- Add gnome-getting-started-docs Requires: once the g-i-s assistant
  is completed, it auto-launches the getting started documentation.
* Tue Feb 16 2016 dimstar@opensuse.org
- Update to version 3.19.2:
  + Fix timezone lookup after locale change.
  + Handle screen resolution changes.
  + Design updates to the timezone page.
  + Don't create a keyring for existing users.
  + Updated translations.
* Mon Feb 15 2016 dimstar@opensuse.org
- Create user 'gnome-initial-setup', which is mandatory to make
  this work.
* Mon Nov 23 2015 zaitor@opensuse.org
- Update to version 3.19.1:
  + Ensure locale region matches the selected language.
  + Sort languages case-insensitively.
  + Updated translations.
* Mon Sep 21 2015 dimstar@opensuse.org
- Update to version 3.18.0:
  + Updated translations.
* Wed Sep  2 2015 zaitor@opensuse.org
- Update to version 3.17.91:
  + Go back to enforcing password policy (bgo#754213).
  + Updated translations.
* Mon Aug 17 2015 zaitor@opensuse.org
- Update to version 3.17.90:
  + Detect enterprise accounts without heuristic (bgo#752980).
  + Don't change keyring password explicitly (bgo#752980).
  + Fix problem with restarting geoclue client.
  + Updated translations.
* Thu Jul 23 2015 zaitor@opensuse.org
- Update to version 3.17.4:
  + Create keyring initially unencrypted.
  + Password page refinements (bgo#735578).
  + Make policy dialog resize properly (bgo#749426).
  + Use correct key for privacy policy (bgo#749545).
  + Handle disabled network better.
  + Avoid a crash on language change (bgo#752134).
  + Make gnome-shell launch first.
  + AVoid a race in launching welcome tour.
  + Updated translations.
* Fri May 22 2015 dimstar@opensuse.org
- Update to version 3.16.3:
  + Avoid keyring problems with preexisting passwordless accounts.
  + Improve password page.
  + Look for the right key in os-release for privacy policy.
  + Make policy dialog resize properly.
  + Updated translations.
* Tue May 12 2015 zaitor@opensuse.org
- Update to version 3.16.2:
  + Updated translations.
* Wed Apr 15 2015 dimstar@opensuse.org
- Update to version 3.16.1:
  + Updated translations.
* Mon Mar 23 2015 dimstar@opensuse.org
- Update to version 3.16.0:
  + Updated translations.
* Wed Mar 18 2015 dimstar@opensuse.org
- Update to version 3.15.92:
  + Stop using deprecated API.
  + Improved keyboard navigation.
  + Adapt to gnome-desktop locale codeset changes.
  + Updated translations.
* Thu Mar  5 2015 dimstar@opensuse.org
- Update to version 3.15.91.1:
  + Port to Webkit2.
  + Updated translations.
- Replace pkgconfig(webkitgtk-3.0) BuildRequires with
  pkgconfig(webkit2gtk-4.0), following upstreams port to WebKit2.
* Tue Mar  3 2015 dimstar@opensuse.org
- Update to version 3.15.91:
  + Fix a possible crash in the network page.
  + Updated translations.
* Wed Feb 25 2015 dimstar@opensuse.org
- Update to version 3.15.90.1:
  + Append ibus input sources.
  + Allow resizing on small screens.
  + Improve account creation dialogs.
  + Move privacy page before timezone.
  + Use the permanent bus name for abrtd.
- Update to version 3.15.90:
  + Add a privacy page.
  + Don't wait for GDM to kill us.
  + Updated translations.
- Add pkgconfig(webkitgtk-3.0) BuildRequires: new dependency.
* Wed Feb 25 2015 dimstar@opensuse.org
- Update to version 3.14.3:
  + Fix a crash in the network page.
  + Append ibus sources to input sources list.
  + Allow resizing on small screens.
  + Use header bars on goa dialogs.
  + Fix a crash in the language page.
  + Hide the window instead of letting gdm kill it.
  + Fix a crash in the keyboard page.
  + Updated translations.
* Thu Nov 13 2014 zaitor@opensuse.org
- Update to version 3.14.2.1:
  + Disable SSLv3 because of POODLE.
- Changes from version 3.14.2:
  + Fix changing the login keyring password.
  + Ensure that we show the selected input source.
  + Preserve system keyboard layouts.
  + Don't choose irrelevant layouts as first level choices.
  + Add a function to detect small screens.
  + Hide images when we have no space for them.
  + Drop the minimum size when we are on a small screen.
  + Updated translations.
- Changes from version 3.14.1:
  + Don't allow to move window.
  + Avoid a crash in input chooser.
  + Require selecting an input source.
  + Updated translations.
* Mon Sep 22 2014 zaitor@opensuse.org
- Update to version 3.14.0:
  + Fix skip button showing up on the last page.
  + Updated translations.
* Wed Sep 17 2014 dimstar@opensuse.org
- Update to version 3.13.7:
  + Refine spacing and alignment on all pages.
  + keyboard: Show suggestions for the current locale.
  + keyboard: Add all IBus engines.
  + keyboard: Ellipsize long labels.
  + Updated translations.
* Mon Sep 15 2014 zaitor@opensuse.org
- Update to version 3.13.6:
  + language: Drop British English to make page smaller.
  + region: Drop, instead show all locales in the language page.
  + keyboard: Show all layouts (in the expanded list).
  + account: Whitelist realmd actions to enable enterprise setup.
  + timezone: Remove icon to make page smaller.
  + Improve keyboard navigation.
  + Bring back existing-user mode.
  + Updated translations.
* Sun Sep  7 2014 zaitor@opensuse.org
- Update to version 3.13.5:
  + language: Don't dim distro logo.
  + timezone: Make page smaller.
  + input: Fix build without ibus.
  + password: Don't hard-enforce strong passwords.
  + Updated translations.
* Sat Aug 16 2014 dimstar@opensuse.org
- Update to version 3.13.4:
  + Account:
  - Improve wording.
  - Update to match control-center.
  + Timezone:
  - Add geoclue integration.
  - Add an icon.
  + Password:
  - Update to match control-center.
  - Properly clean up signal handler.
  + Keyring: Open session.
  + Copy-worker: Run in early initialization phase.
  + Updated translations.
- Add pkgconfig(geoclue-2.0) BuildRequires: new dependency.
* Sat Aug 16 2014 wr@rosenauer.org
- Set RPM group to System/GUI/GNOME to match other GNOME packages.
* Wed Jul 23 2014 dimstar@opensuse.org
- Update license to be GPL-2.0: matches COPYING and most files.
  + Two files in the tarball are marked to be GPL-3.0. Upstream has
    been contacted to verify if this is indeed correct (which would
    result the entire binary to become GPL-3.0+, bgo#733593).
* Tue Jul  1 2014 dimstar@opensuse.org
- Update to version 3.12.1:
  + Fix an untranslatable string.
  + Updated translations.
* Tue Mar 25 2014 dimstar@opensuse.org
- Update to version 3.12.0:
  + Updated translations.
* Fri Mar 21 2014 dimstar@opensuse.org
- Update to version 3.11.92:
  + Build fixes:
  - Initialize automake earlier.
  - Enable maintainer mode.
  + Update titlebar on locale change.
  + Use distro logo instead of GNOME foot.
  + Timezone Dialog:
  - Ensure map is properly allocated.
  - Draw location marker pixel-aligned.
  + Updated translations.
* Wed Mar  5 2014 dimstar@opensuse.org
- Update to version 3.11.91:
- Initial package, version 3.11.91.
